import jwo.landserf.structure.*;   // For RasterMap class.
import jwo.landserf.process.io.*;  // For file reading/writing.

// **********************************************************
/** Converts an ArcGIS raster text ' file into a LandSerf
  * raster map. This version deals with larger files sizes than
  * the one used in LandSerf 2.0.
  * @author Jo Wood
  * @version 1.0, 25th, March, 2004
  */
// **********************************************************

public class ArcTextRasterConvert
{
    //------------------ Starter Method -----------------
    
    /** Starts the Arc raster text converter.
      * @param args Command line arguments. Should be the name
      * of the file to convert.
      */
    public static void main(String[] args)
    {
        
        boolean removeVoids = false;
        
        if ((args == null) || (args.length != 1))
        {
            System.err.println("Usage: ArcTextRasterConvert <arcRasterFile>");
            return;   
        }
        
        String fileName = args[0];

        new ArcTextRasterConvert(fileName);
    }


    //------------------- Constructor -------------------

    /** Converts the given ArcGIS text raster file into LandSerf 
      * format. Will save the LandSerf file with the same name but
      * with a .srf extension.
      */
    public ArcTextRasterConvert(String inFileName)
    {
        // Create output file name.
        int dotPosition = inFileName.lastIndexOf(".");
        if (dotPosition <= 0)
            dotPosition = inFileName.length();
            
        String outFileName = inFileName.substring(0,dotPosition)+".srf";

        // Read in the data from the HGT file.
        System.out.println("Reading file: "+inFileName);
        ArcReader arcReader = new ArcReader();
        RasterMap raster = arcReader.readRaster(inFileName);
        
        if (raster == null)
        {
            System.err.println("Problem reading input file\n\t"+arcReader.getLastError());
            return;
        }
        
        // Write new raster to file.
        System.out.println("Writing output file as "+outFileName);
        LandSerfIO.write(raster,outFileName);
        
        System.out.println("Conversion completed.");
        
    }   
}
